@@ -1,15 +1,10 @@
-import abc
-from collections import namedtuple
-from sqlite3 import Connection
+import base64
 from typing import List
-
 import numpy as np
-
 from tileset_analyzer.data_source.ds_utils import get_attr
 from tileset_analyzer.data_source.mbtiles.sqllite_utils import create_connection
 from tileset_analyzer.data_source.tile_source import TileSource
 from tileset_analyzer.entities.job_param import JobParam, CompressionType
-from tileset_analyzer.entities.layer_info import LayerInfo
 from tileset_analyzer.entities.layer_level_size import LayerLevelSize, TileItemSize
 from tileset_analyzer.entities.level_size import LevelSize
 from tileset_analyzer.entities.tile_item import TileItem
@@ -21,7 +16,6 @@ import pandas as pd
 from tileset_analyzer.entities.tileset_info import TilesetInfo
 import os
 from pathlib import Path
-import base64
 from tileset_analyzer.readers.vector_tile.engine import VectorTile
 import gzip
 import multiprocessing
@@ -40,13 +34,29 @@ class MBTilesSource(TileSource):
 
     def count_tiles(self) -> int:
         cur = self.conn.cursor()
-        cur.execute(SQL_COUNT_TILES)
+        sql = SQL_COUNT_TILES.format(
+            **{
+                'tiles': self.job_param.mbtiles_tbl.tiles,
+                'tile_row': self.job_param.mbtiles_tbl.tile_row,
+                'tile_column': self.job_param.mbtiles_tbl.tile_column,
+                'zoom_level': self.job_param.mbtiles_tbl.zoom_level,
+                'tile_data': self.job_param.mbtiles_tbl.tile_data
+            })
+        cur.execute(sql)
         count = cur.fetchone()[0]
         return count
 
     def count_tiles_by_z(self) -> List[LevelCount]:
         cur = self.conn.cursor()
-        cur.execute(SQL_COUNT_TILES_BY_Z)
+        sql = SQL_COUNT_TILES_BY_Z.format(
+            **{
+                'tiles': self.job_param.mbtiles_tbl.tiles,
+                'tile_row': self.job_param.mbtiles_tbl.tile_row,
+                'tile_column': self.job_param.mbtiles_tbl.tile_column,
+                'zoom_level': self.job_param.mbtiles_tbl.zoom_level,
+                'tile_data': self.job_param.mbtiles_tbl.tile_data
+            })
+        cur.execute(sql)
         rows = cur.fetchall()
         result: List[LevelCount] = []
         for row in rows:
@@ -54,7 +64,6 @@ class MBTilesSource(TileSource):
         return result
 
     def _get_agg_tile_size_z(self, agg_type: str) -> List[LevelSize]:
-        sql = None
         if agg_type == 'SUM':
             sql = SQL_SUM_TILE_SIZES_BY_Z
         elif agg_type == 'MIN':
@@ -66,6 +75,14 @@ class MBTilesSource(TileSource):
         else:
             raise 'UNKNOWN AGG TYPE'
 
+        sql = sql.format(
+            **{
+                'tiles': self.job_param.mbtiles_tbl.tiles,
+                'tile_row': self.job_param.mbtiles_tbl.tile_row,
+                'tile_column': self.job_param.mbtiles_tbl.tile_column,
+                'zoom_level': self.job_param.mbtiles_tbl.zoom_level,
+                'tile_data': self.job_param.mbtiles_tbl.tile_data
+            })
         cur = self.conn.cursor()
         cur.execute(sql)
         rows = cur.fetchall()
@@ -76,15 +93,31 @@ class MBTilesSource(TileSource):
 
     def _get_all_tiles(self) -> List[TileItem]:
         cur = self.conn.cursor()
-        cur.execute(SQL_ALL_TILES)
+        sql = SQL_ALL_TILES.format(
+            **{
+                'tiles': self.job_param.mbtiles_tbl.tiles,
+                'tile_row': self.job_param.mbtiles_tbl.tile_row,
+                'tile_column': self.job_param.mbtiles_tbl.tile_column,
+                'zoom_level': self.job_param.mbtiles_tbl.zoom_level,
+                'tile_data': self.job_param.mbtiles_tbl.tile_data
+            })
+        cur.execute(sql)
         rows = cur.fetchall()
-        result: List[LevelSize] = []
+        result: List[TileItem] = []
         for row in rows:
             result.append(TileItem(row[0], row[1], row[2], row[3]))
         return result
 
     def _set_tilesize_z_dataframe(self):
-        query = SQL_LIST_TILE_SIZES_BY_Z
+        sql = SQL_LIST_TILE_SIZES_BY_Z.format(
+            **{
+                'tiles': self.job_param.mbtiles_tbl.tiles,
+                'tile_row': self.job_param.mbtiles_tbl.tile_row,
+                'tile_column': self.job_param.mbtiles_tbl.tile_column,
+                'zoom_level': self.job_param.mbtiles_tbl.zoom_level,
+                'tile_data': self.job_param.mbtiles_tbl.tile_data
+            })
+        query = sql
         cur = self.conn.cursor()
         self.tiles_size_z_df = pd.read_sql(query, self.conn)
         cur.close()
@@ -93,7 +126,6 @@ class MBTilesSource(TileSource):
         self.tiles_size_z_df = None
 
     def _get_agg_tile_size_percentiles_z(self, percentile_type: str) -> List[LevelSize]:
-        quantile = None
         if percentile_type == '50p':
             quantile = 0.5
         elif percentile_type == '85p':
@@ -142,7 +174,7 @@ class MBTilesSource(TileSource):
 
     def _processed_data(self, data):
         if self.job_param.compressed is False:
-            return data
+            return base64.encodestring(data)
 
         if self.job_param.compression_type == CompressionType.GZIP:
             return gzip.decompress(data)
@@ -422,4 +454,3 @@ class MBTilesSource(TileSource):
         self._preprocess_tile_layer_sizes_clear()
 
         return result
-
