@@ -1,5 +1,5 @@
 class TileItem:
-    def __init__(self, x: int, y: int, z: int, data: any):
+    def __init__(self, x: int, y: int, z: int, data: bytes):
         self.x = x
         self.y = y
         self.z = z
